Aggregator.App.ndjson\_decoder
==============================

.. automodule:: Aggregator.App.ndjson_decoder

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
   
      Decoder
   
   

   
   
   



